Module services

Module services 

PDK Integration Test Framework predefined services.

This module provides predefined services for integration testing scenarios. It includes mock services, test utilities, and Flex Gateway configurations commonly used in PDK integration tests.

Available services

  • flex: Flex Gateway service configurations and utilities
  • httpmock: HTTP mock service for API testing
  • httpbin: HTTP testing service with various endpoints
  • grpcbin: gRPC testing service for protocol testing
  • gripmock: gRPC mock service for service mocking

Modules

flex
Flex Gateway service configurations
gripmock
gRPC mock service for integration testing
grpcbin
gRPC testing service for integration testing
httpbin
HTTP testing service for integration testing
httpmock
HTTP mock service for integration testing