Module httpbin

Module httpbin 

HTTP testing service for integration testing

This module provides predefined types and configurations for HTTPBin services in integration tests. HTTPBin is a simple HTTP request and response service useful for testing HTTP clients and APIs.

Structs

HttpBin
Represents a HttpBin service instance.
HttpBinConfig
Struct to manage the HTTPBin configuration.
HttpBinConfigBuilder
Builder for HttpBinConfig.