pub struct TestComposite { /* private fields */ }Expand description
Main test environment orchestrator for integration tests.
Implementations
Sourceimpl TestComposite
impl TestComposite
Sourcepub fn builder() -> TestCompositeBuilder
pub fn builder() -> TestCompositeBuilder
Creates a new builder for configuring test environments.
Sourcepub fn service<T: Service + 'static>(&self) -> Result<T, TestError>
pub fn service<T: Service + 'static>(&self) -> Result<T, TestError>
Gets a service instance by its type. Returns the first configured service of the specified type.
Sourcepub fn service_by_hostname<T: Service + 'static>(
&self,
name: &str,
) -> Result<T, TestError>
pub fn service_by_hostname<T: Service + 'static>( &self, name: &str, ) -> Result<T, TestError>
Gets a service instance by its hostname. Returns the service with the specified hostname and type.