pub enum TestError {
Startup(String),
Io(Error),
Docker(DockerError),
NotSupportedConfig(String),
UnknownService(&'static str),
UnknownServiceHostname(String),
UnavailableRuntime(UnavailableRuntimeError),
UnavailableMultiThread,
UnavailablePorts,
UnavailableDocker(DockerError),
CredentialRetrieval(CredentialRetrievalError),
}Expand description
Error type for integration tests.
Variants
Startup(String)
Represents an startup error.
Io(Error)
Represents a low-level I/O error.
Docker(DockerError)
Represents a low-level Docker error.
NotSupportedConfig(String)
Represents an error indicating a wrong service configuration.
UnknownService(&'static str)
Represents an error indicating that there is not a known service with the specified name.
UnknownServiceHostname(String)
Represents an error indicating that there is not a known service with the specified hostname.
Represents an error indicating that the async runtime was not configured.
Represents an error indicating that the underlying async runtime does not support multithreading.
Represents an error there are not ports available to bind services.
Represents an error indicating that the Docker daemon is not available.
CredentialRetrieval(CredentialRetrievalError)
Represents an error indicating that credentials cannot be retrieved.