pub struct TestCompositeBuilder { /* private fields */ }Expand description
Builder for configuring and creating test environments.
This builder is used to configure the test environment with the services that will be used in the test. It provides an API for adding services and configuring them.
Implementations
Sourceimpl TestCompositeBuilder
impl TestCompositeBuilder
Sourcepub fn with_service<C: Config + 'static>(self, config: C) -> Self
pub fn with_service<C: Config + 'static>(self, config: C) -> Self
Configures a service with the provided configuration. The service will be started when the test environment is built. Each service must have a unique hostname.
Sourcepub async fn build(self) -> Result<TestComposite, TestError>
pub async fn build(self) -> Result<TestComposite, TestError>
Builds the test environment with all configured services.
Starts Docker containers, creates networks and initializes all services.
Returns a TestComposite that can be used to access the services.